@@ -5,10 +5,10 @@ use strict;
 use warnings;
 
 package Log::Log4perl::Appender::RabbitMQ;
-$Log::Log4perl::Appender::RabbitMQ::VERSION = '0.200002';
+$Log::Log4perl::Appender::RabbitMQ::VERSION = '1.141470';
 our @ISA = qw/ Log::Log4perl::Appender /;
 
-use Net::AMQP::RabbitMQ 2.30000;
+use Net::AMQP::RabbitMQ 0.004002;
 use Readonly;
 
 Readonly my $CHANNEL => 1;
@@ -26,6 +26,16 @@ sub new {
         require Test::Net::RabbitMQ;
     }
 
+    my $self = bless {
+        host        => $args{host}        || 'localhost',
+        routing_key => $args{routing_key} || '%c'       ,
+        declare_exchange => $args{declare_exchange},
+    }, $class;
+
+    # set a flag that tells us to do routing_key interpolation
+    # only if there are things to interpolate.
+    $self->{interpolate_routing_key} = 1 if $self->{routing_key} =~ /%c|%p/;
+
     # Store any given exchange options for declaring an exchange
     my %exchange_options;
     for my $name (qw/
@@ -39,6 +49,7 @@ sub new {
         (my $declare_param_name = $name) =~ s/(.*)_exchange$/$1/;
         $exchange_options{$declare_param_name} = $args{$name} if exists $args{$name};
     }
+    $self->{exchange_options} = \%exchange_options;
 
     # Store any given publish options for use when log is called
     my %publish_options;
@@ -49,6 +60,7 @@ sub new {
     /) {
         $publish_options{$name} = $args{$name} if exists $args{$name};
     }
+    $self->{publish_options} = \%publish_options;
 
     # use any given connect options in connect
     my %connect_options;
@@ -60,42 +72,18 @@ sub new {
        channel_max
        frame_max
        heartbeat
-       ssl
-       ssl_verify_host
-       ssl_cacert
-       ssl_init
-       timeout
     /) {
         $connect_options{$name} = $args{$name} if exists $args{$name};
     }
 
-    # this can be created once as there are no parameters
-    my $mq = $RabbitMQClass->new();
-
-    my $self = bless {
-        host        => $args{host}        || 'localhost',
-        routing_key => $args{routing_key} || '%c'       ,
-        declare_exchange => $args{declare_exchange},
-        connect_options  => \%connect_options,
-        exchange_options => \%exchange_options,
-        publish_options  => \%publish_options,
-        mq               => $mq,
-        _is_connected    => 0,
-    }, $class;
-
-    # set a flag that tells us to do routing_key interpolation
-    # only if there are things to interpolate.
-    $self->{interpolate_routing_key} = 1 if $self->{routing_key} =~ /%c|%p/;
-
     # Create a new connection
     eval {
-        # connect on construction to make finding errors early easier
-        $self->_connect_cached();
+        $self->{mq} = _connect_cached($self->{host}, \%connect_options);
 
         # declare the exchange if declare_exchange is set
-        $mq->exchange_declare(
-            $CHANNEL,
-            $self->{publish_options}{exchange},
+        $self->{mq}->exchange_declare(
+            $CHANNEL, 
+            $self->{publish_options}{exchange}, 
             $self->{exchange_options},
         ) if $self->{declare_exchange};
 
@@ -107,23 +95,39 @@ sub new {
     return $self;
 }
 
-##################################################
-sub _connect_cached {
-##################################################
-    my $self = shift;
 
-    my $mq = $self->{mq};
+##################################################
+# this closure provides a private class method
+# that will connect to RabbitMQ and cache that
+# connection. The next time it's called with
+# the same params it returns the cached connection.
+{
+    my %connection_cache;
 
-    if (!$self->{_is_connected} || $$ != $self->{pid}) {
-        #warn "INFO connecting to RabbitMQ\n";
-        $mq->connect($self->{host}, $self->{connect_options});
+    ##################################################
+    sub _connect_cached {
+    ##################################################
+        my $host = shift;
+        my $connect_options = shift;
+
+        # Create a cache key from the connection options and the host
+        no warnings 'uninitialized';
+        my $cache_key = join(':', $host, sort %$connect_options);
+        use warnings;
+
+        return $connection_cache{$cache_key} if $connection_cache{$cache_key};
+
+        # Create new RabbitMQ object & connection, open channel 1
+        my $mq = $RabbitMQClass->new();
+        $mq->connect($host, $connect_options);
         $mq->channel_open($CHANNEL);
-        $self->{_is_connected} = 1;
-        # remember pid on connect because forking requires to reconnect
-        $self->{pid} = $$;
-    }
 
-    return $mq;
+        # Cache RabbitMQ object
+        $connection_cache{$cache_key} = $mq;
+
+        # Return the RabbitMQ object and the channel we used
+        return $mq;
+    }
 }
 
 ##################################################
@@ -131,7 +135,12 @@ sub log {
 ##################################################
     my ($self, %args) = @_;
 
-    # customize the routing key for this message by
+    my $mq = $self->{mq};
+
+    # do nothing if the Net::AMQP::RabbitMQ object is missing
+    return unless $mq;
+
+    # customize the routing key for this message by 
     # inserting category and level if interpolate_routing_key
     # flag is set
     my $routing_key = $self->{routing_key};
@@ -140,37 +149,20 @@ sub log {
         $routing_key =~ s/%p/$args{log4p_level}/g;
     }
 
-    my $successful = 0;
-    my $try = 0;
-    my $retries = 1;
-    while (!$successful && $try <= $retries) {
-        $try++;
-
-        # publish the message to the specified group
-        eval {
-            my $mq = $self->_connect_cached();
-
-            $mq->publish($CHANNEL, $routing_key, $args{message}, $self->{publish_options});
-            $successful = 1;
-            1;
-        } or do {
-            # If you got an error warn about it and clear the
-            # Net::AMQP::RabbitMQ object so we don't keep trying
-            warn "ERROR logging to RabbitMQ via ".ref($self).": $@\n";
-            # force a reconnect
-            $self->{_is_connected} = 0;
-        };
-    }
+    # publish the message to the specified group
+    eval {
+        $mq->publish($CHANNEL, $routing_key, $args{message}, $self->{publish_options});
+        1;
+    } or do {
+        # If you got an error warn about it and clear the 
+        # Net::AMQP::RabbitMQ object so we don't keep trying
+        warn "ERROR logging to RabbitMQ via ".ref($self).": $@\n";
+        $self->{mq} = undef;
+    };
 
     return;
 }
 
-sub DESTROY {
-    my $self = shift;
-    $self->{mq}->disconnect()
-        if exists $self->{mq} && defined $self->{mq};
-}
-
 1;
 
 __END__
@@ -185,7 +177,7 @@ Log::Log4perl::Appender::RabbitMQ - Log to RabbitMQ
 
 =head1 VERSION
 
-version 0.200002
+version 1.141470
 
 =head1 SYNOPSIS
 
@@ -246,16 +238,6 @@ Defaults to localhost.
 
 =item heartbeat
 
-=item ssl
-
-=item ssl_verify_host
-
-=item ssl_cacert
-
-=item ssl_init
-
-=item timeout
-
 =back
 
 =head3 Exchange Options
@@ -333,23 +315,13 @@ methods:
 
 =back
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
+=head1 AUTHOR
 
 Trevor Little <bundacia@tjlittle.com>
 
-=item *
-
-Alexander Hartmaier <abraxxa@cpan.org>
-
-=back
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Alexander Hartmaier.
+This software is copyright (c) 2014 by Trevor Little.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
